@@ -11,7 +11,7 @@ use Scalar::Util qw/weaken/;
 use Tree::R;
 
 
-our $VERSION = '2.63_001';
+our $VERSION = '2.65_001';
 
 my $little_endian_sys = unpack 'b', (pack 'S', 1 );
 
@@ -423,11 +423,13 @@ sub _get_shp_shx_header_value {
     my $self = shift;
     my $val  = shift;
 
-    if (!($self->{'shx_' . $val} || $self->{'shp_' . $val})) {
+    if (!defined ($self->{'shx_' . $val} || $self->{'shp_' . $val})) {
         $self->_read_shx_header();
     }
 
-    return $self->{'shx_' . $val} || $self->{'shp_' . $val} || undef;
+    return defined($self->{'shx_' . $val})
+      ? $self->{'shx_' . $val}
+      : $self->{'shp_' . $val};
 }
 
 #  factory these
@@ -521,7 +523,7 @@ sub bounds_contains_point {
 }
 
 sub file_version {
-    shift()->_get_shp_shx_header_value('file_version');
+    shift()->_get_shp_shx_header_value('version');
 }
 
 sub shape_type {
@@ -864,6 +866,7 @@ Geo::ShapeFile - Perl extension for handling ESRI GIS Shapefiles.
 
   my $shapefile = Geo::ShapeFile->new('roads');
 
+  #  note that IDs are 1-based
   foreach my $id (1 .. $shapefile->shapes()) {
     my $shape = $shapefile->get_shp_record($id);
     # see Geo::ShapeFile::Shape docs for what to do with $shape
@@ -894,12 +897,13 @@ base) formats.
 =over 4
 
 =item new ($filename_base)
+
 =item new ($filename_base, {no_cache => 1})
 
 Creates a new shapefile object.  The first argument is the basename
 for your data (there is no need to include the extension, the module will automatically
 find the extensions it supports).  For example if you have data files called
-roads.shp, roads.shx, and roads.dbf, use 'Geo::ShapeFile->new("roads");' to
+roads.shp, roads.shx, and roads.dbf, use C<< Geo::ShapeFile->new("roads"); >> to
 create a new object, and the module will load the data it needs from the
 files as it needs it.
 
@@ -931,7 +935,7 @@ in the shp file header.
 
 =item lower_left_corner() lower_right_corner()
 
-Returns a Geo::ShapeFile::Point object indicating the respective corners.
+Returns a L<Geo::ShapeFile::Point> object indicating the respective corners.
 
 =item height() width()
 
@@ -975,7 +979,7 @@ value.
 
 Returns the number of shapes contained in the current shp/shx file.  This is
 the value that allows you to iterate through all the shapes using
-'for(1 .. $obj->shapes()) {'.
+C<< for(1 .. $obj->shapes()) { >>.
 
 =item records()
 
